// **********************************************************************
//
//                           EXBSLV
//
//  This program reads a LP problem from an MPS file, and solves the
//  the problem with the Interior-Point Barrier method using the
//  Primal-Dual algorithm.
//
// **********************************************************************

#include <string.h>
#include <stdlib.h>
#include <math.h>
#include <assert.h>
#include "ekk_c_api.h"

int main()
{
    // Initialize OSL environment   
    EKKContext * env;
    env = ekk_initializeContext();

    // Create an OSL model "test"   
    EKKModel * test;
    test = ekk_newModel(env,NULL);

    // Read model data from MPS file
    int rtcod = ekk_importModel(test,"exlp6.mps");

    // Presolve the model           
    rtcod = ekk_preSolve(test,3,"presolve3");

    // Solve using the barrier method  -- no crossover bto simplex   
    rtcod = ekk_barrier(test,0);

    // Postsolve the model          
    rtcod = ekk_postSolve(test,"presolve3");

    // Print the solution           
    rtcod = ekk_printSolution(test);

    // Delete the model             
    rtcod = ekk_deleteModel(test);

    // OSL Destructor               
    ekk_endContext(env);

    return 0;
}
