// -------------------------------------------------------------------
//                             EXGMIP
//
// This program reads a MIP problem from an MPS file, transforms
// it to a 0/1 MIP problem, solves the problem with the branch-and-
// bound method and transforms back the optimal solution to the
// original variables.
// ------------------------------------------------------------------- 

#include <string.h>
#include <stdlib.h>
#include <math.h>
#include <assert.h>
#include "ekkc.h"
#include "ekk_c_api.h"

// MIP Test
int main()
{
    // Initialize OSL environment 
    EKKContext * env;
    env = ekk_initializeContext();

    // Create model genmipmodel   
    EKKModel *genmipmodel;
    genmipmodel=ekk_newModel(env,NULL);

    // Create a temporary model binmodel
    EKKModel *binmodel;
    binmodel=ekk_newModel(env,NULL);

    // Set to print column solutions only for genmipmodel
    int rc = ekk_setIsolmask(genmipmodel,6);

    // Read model data from MPS file
    rc = ekk_importModel(genmipmodel,"grp40.mps");

    // Copy genmipmodel data into  binmodel
    rc = ekk_copyModel(binmodel, genmipmodel);

    // Transform model into a 0/1 MIP using a LOG transformation 
    int  log=1;
    rc = ekk_makeBinary(binmodel,log);

    // Increase  maximum allowable rows by 1000
    rc = ekk_setImaxrows(binmodel,ekk_getInumrows(binmodel)+1000);

    // Solve model by simplex     
    rc = ekk_eitherSimplex(binmodel);

#if 0
    // Create work space to be able to make V2 type calls
    double * dspace = (double*)malloc(3000000*sizeof(double));
    rc = ekk_loadDspace(binmodel, dspace, 3000000);

    // Preprocess the MIP
    long rtcod;
    ekkmpre(&rtcod,dspace,1);

    // Solve by branch-and-bound  
    ekkmslv(&rtcod,dspace,1,0,0);

    // Copy data from V2 work space to V3 object and free V2 work space
    rc = ekk_unloadDspace(binmodel,dspace);
    free(dspace);
#else

    // Preporcess the MIP
    rc = ekk_integerPresolve(binmodel,NULL,NULL,0);

    // Solve by branch and bound
    ekk_branchAndBound(binmodel,NULL,NULL);
#endif

    // Transform the binmodel back to original genmipmodel      
    rc = ekk_fromBinary(genmipmodel, binmodel);

    // Delete the temporary model 
    rc = ekk_deleteModel(binmodel);

    // Print the solution         
    rc = ekk_printSolution(genmipmodel);

    // Delete genmipmodel         
    rc = ekk_deleteModel(genmipmodel);

    // OSL Destructor
    ekk_endContext(env);

    return 0;
}
